@@ -743,10 +743,13 @@ class SagemakerFeatureStore:
 
         # Check schema
         fg_schema = fg_config["features_info"]
+        fg_schema_keys = set([item["FeatureName"] for item in fg_schema])
+
         get_one_data = data[0]
-        for item in fg_schema:
-            if item["FeatureName"] not in get_one_data:
-                raise Exception("Invalid schema in input_data")
+        input_keys = set(list(get_one_data.keys()))
+
+        if fg_schema_keys != input_keys:
+            raise Exception("Invalid schema in input_data")
 
         # Checkers
         is_dynamodb = (
